# encoding: utf-8
"""
F3_4B.py

Generate the trajectory-and-spike plots and rate maps for selected clusters in
the 2D environments
"""

import numpy as np
import matplotlib.pylab as plt

from tdb.data import get_group
from tdb.td_maps import plot_boundaries
from tdb.plot_rate_map import locate_spike, plot_traj_and_spike, plot_ratemap 

def plot_select_cluster(board='simple'):
    plt.close('all')
    
    # Set the plot type and the cluster list
    plt_types = ['spike','rate','rate_bd']
    if board == 'complex':
        cl_list = [ ((740,3,3),'t4c11'), ((637,5,3),'t2c4'), ((576,6,2),'t6c5'), \
                    ((576,9,1),'t6c4'), ((579,28,1),'t5c3'), ((579,28,1),'t3c3'), \
                    ((576,4,3),'t3c1'), ((637,5,3),'t10c6'), ((576,9,1),'t6c5'), \
                    ((577,8,1),'t1c6'), ((740,4,3),'t2c2'), ((579,29,1),'t2c6') ]
    elif board == 'simple':
        cl_list = [ ((740,5,1),'t14c8'), ((710,18,1),'t10c3'),\
                    ((740,6,2),'t13c10'), ((746,5,2),'t10c3'), ((740,5,2),'t13c9'),\
                    ((740,5,4),'t4c6'), ((710,17,4),'t8c11'), ((710,18,1),'t8c4'),\
                    ((740,5,2),'t5c4'), ((740,5,2),'t4c5') ]
    N = len(cl_list)

    data_list = []
    for rds, tc in cl_list:
        for plt_type in plt_types:
            data_list.append( (rds, tc, plt_type) )

    # For each cluster/plot type generate the corresponding plot
    plt_cnt = 1
    for rds, cl, plt_type in data_list:
        # Load the trajectory and spike data
        session = get_group(rds=rds)
        x, y, ts = \
            [ session._v_children[key] for key in ['x','y','t_pos'] ]
        t_spk = session._v_children[cl]
        x_spk, y_spk = locate_spike(ts,x,y,t_spk)

        # Generate the plots
        ax = plt.subplot(N,3,plt_cnt)
        if 'spike' in plt_type:
            plot_traj_and_spike(ax,rds,x,y,x_spk,y_spk)
        elif 'rate' in plt_type:
            H_rate, mask = plot_ratemap(ax,session,t_spk,rds,cbar=True,smooth='gaussian')
            if 'bd' in plt_type:
                plot_boundaries(*rds,**{'c':'r','alpha':0.5,'lw':1})
            print ('cell %d: rat %d, day %d, session %d, %s, peak rate = %.2f' \
                % ((plt_cnt/3+1,)+rds+(cl,np.max(H_rate[~mask]))) )

        # Format the plots
        ax.axis([-70,70,-70,70])
        ax.set_aspect('equal')
        ax.set_axis_off()
        if (plt_cnt%3) == 1:
            ttl = ax.set_title( 'cell %d: rat %d, day %d, session %d, %s' \
                % ((plt_cnt/3+1,)+rds+(cl,)),fontsize=8,fontname='Arial',loc='left')
            if board == 'complex':
                ttl.set_position([0,0.95])
            elif board == 'simple':
                ttl.set_position([0,0.92])

        plt_cnt += 1

    plt.subplots_adjust(left=0.01,right=0.99,bottom=0.01,top=0.95,wspace=0.02, hspace=0.05)

    f = plt.gcf()
    if board == 'complex':
        f.set_size_inches(2,9.5,forward=True)
        fn = './F3.png'
    elif board == 'simple':
        f.set_size_inches(2,8,forward=True)
        fn = './F4B.png'
    f.savefig(fn,dpi=1000)

# end of FUNCTION plot_select_cluster

