# encoding: utf-8
"""
cross_session.py
"""

import tables as tb
import numpy as np

from core.analysis import AbstractAnalysis

from scanr.cluster import string_to_quality

from tdb.data import get_tdb_file, get_group
from tdb.meta import get_maze_list


class SLCrossSessionAna(AbstractAnalysis):
    datadir = './SLCrossSession'
    label = 'SL cross session'

    def collect_data( self, min_quality='Fair', platform='leather' ):
        tdb_file = get_tdb_file()
        field_table = tdb_file.root.spatial.fields
        q_min = string_to_quality( min_quality )

        self.results = {}

        if min_quality == 'Fair':
            query = '(area=="CA1")&(quality!="Poor")&(quality!="Marginal")'
        elif min_quality == 'Marginal':
            query = '(area=="CA1")&(quality!="Poor")'
        else:
            print 'Not implemented yet'
            return
            
        clust_list = []
        for field in field_table.where(query):
            rat, day, maze = field['rat'], field['day'], field['session']
            if (rat,day) == (710,17): # SHF platform placed in wrong orientation
                continue
            tc = 't%dc%d' % (field['tt'],field['cl'])
            clust_list.append( (field['rat'],field['day'],tc) )
        clust_list = list( set(clust_list) )

        data_list = []
        for rat, day, tc in clust_list:
            pass_filter = np.zeros(4, dtype=bool) # False array
            # only use standard SL data, # of maze == 4
            for maze in get_maze_list(rat,day):
                session = get_group( rds=(rat,day,maze) )
                if session._v_attrs['platform'] != platform:
                    continue
                if tc in session._v_children.keys():
                    clust = session._v_children[tc]
                    quality = string_to_quality( clust._v_attrs['quality'] )
                    pass_filter[maze-1] =  quality >= q_min

            #if np.sum(pass_filter) == 4: # all sessions pass quality threshold
            #    data_list.append( (rat,day,tc) )

            P = pass_filter[:]
            if (P[0] or P[1]) and P[2] and P[3]:
                data_list.append( (rat,day,tc) )

        tdb_file.close()

        self.results['data_list'] = data_list
        self.out('%d clusters collected for %s session' \
            % (len(data_list),platform) )
        self.out('Done')
    # end of METHOD collect_data
