# encoding: utf-8

"""
preview.py
"""

# Library imports
import numpy as np
import matplotlib.pyplot as plt

# ---------------------------------------------------------------------------------

def plot_2db_data(pos_file, cl_file, bin_size=8, interp=None, speed_filter=True): 
    HEIGHT = 480
    WIDTH = 720
    START = long(117961310439)
    END = long(119154505166)
    OCC_THRD = 10
    SPEED_THRD = 4.0

    VERTICES = ((495,345),(512,122),(265,100),(243,325))    # (x,y); NW,SW,SE,NE
    INTERSECT = ((440,256),(321,184)) # NW,SE

    def plot_edges(x_scale,y_scale):
        kwargs = {'c':'k','lw':2}

        v = np.array([ ((WIDTH-Vx)*x_scale,Vy*y_scale) for Vx, Vy in VERTICES ])
        w = np.array([ ((WIDTH-Wx)*x_scale,Wy*y_scale) for Wx, Wy in INTERSECT ])
        P1, P2, P3, P4 = v[0], v[1], v[2], v[3]
        I1, I2 = w[0], w[1]

        r = 21.5 / 57
        D1 = r*P2 + (1-r)*P4
        D2 = r*P4 + (1-r)*P2

        r = 10.0 / 40
        O1 = r*P4 + (1-r)*P1
        O4 = r*P2 + (1-r)*P3

        r = 14.5 / 40
        O2 = r*P1 + (1-r)*P4
        O3 = r*P4 + (1-r)*P3
        O5 = r*P3 + (1-r)*P2
        O6 = r*P2 + (1-r)*P1

        plt.plot( *zip(*(list(v)+[P1,])),**kwargs )
        plt.plot( *zip(*[P2,P4]),**kwargs ) # diagonal
        plt.plot( *zip(*[I1,O1]),**kwargs )
        plt.plot( *zip(*[D1,O2]),**kwargs )
        plt.plot( *zip(*[D1,O6]),**kwargs )
        plt.plot( *zip(*[I2,O4]),**kwargs )
        plt.plot( *zip(*[D2,O5]),**kwargs )
        plt.plot( *zip(*[D2,O3]),**kwargs )
        #plt.scatter( *zip(*w),s=20,c='k',marker='o' )
    # end of FUNCTION plot_edges

    ts, x, y, angles = np.loadtxt(pos_file,comments='%',delimiter=',',unpack=True)
    ts_ori, x_ori, y_ori = ts[:], x[:], y[:]
    ts = ts.astype(long)
    fs = 1000000.0 / np.median( np.diff(ts) )
    speed = np.r_[0.0, np.sqrt(np.diff(x)**2+np.diff(y)**2)*fs ]
    valid = np.logical_and( np.logical_and(ts>=START, ts<END), \
        np.logical_and(np.r_[True,np.diff(ts)>0], np.logical_or(x>0,y>0)) ) 
    ts, x, y = ts[valid], x[valid], y[valid]
    # confirm
    if (np.diff(ts)<0).any():
        print 'Incorrect timestamps'

    with open(cl_file) as f:
        lines = (line for line in f if not line.startswith('%'))
        spikes = np.loadtxt(lines,comments='%',delimiter=',',skiprows=2, \
            usecols=[17,],unpack=True)
    f.close()
    print len(spikes)
    spikes = spikes.astype(long)
    spikes = np.sort( spikes[(spikes>=START)&(spikes<END)] )
    ptr = 0
    spk_x, spk_y = [], []
    count = 0
    for spk in spikes:
        while ptr<len(ts) and ts[ptr]<spk:
            ptr += 1
        if (ptr==0) or (ptr==len(ts)):
            continue
        v = np.sqrt((x[ptr]-x[ptr-1])**2+(y[ptr]-y[ptr-1])**2) * fs
        interp_r = float(spk-ts[ptr-1]) / (ts[ptr]-ts[ptr-1]) 
        if speed_filter and (v<SPEED_THRD):
            count += 1
            continue
        spk_x.append( x[ptr-1] + (x[ptr]-x[ptr-1])*interp_r )
        spk_y.append( y[ptr-1] + (y[ptr]-y[ptr-1])*interp_r )
    spk_x = np.array( spk_x )
    spk_y = np.array( spk_y )
    print '%d spikes excluded by velocity filter (%.2f cm/s)' % (count,SPEED_THRD)

    if speed_filter:
        valid = np.logical_and( valid, speed>4.0 )
    ts, x, y = ts_ori[valid], x_ori[valid], y_ori[valid]

    y_nbin = HEIGHT/bin_size
    y_edges = np.linspace(0,HEIGHT,y_nbin+1)
    x_nbin = WIDTH/bin_size
    x_edges = np.linspace(0,WIDTH,x_nbin+1)

    plt.figure('traj')
    plt.hold('on')
    plt.plot(WIDTH-x,y,'k-')
    plt.plot(WIDTH-spk_x,spk_y,'r.')
    plt.axis([0,WIDTH,0,HEIGHT])

    plt.figure('occ_norm')
    H_traj,y_tmp,x_tmp = np.histogram2d(y,x,bins=[y_edges,x_edges])
    H_traj = np.fliplr( H_traj.astype('d') )
    peak = np.max(H_traj)
    H_traj[ H_traj==0 ] = -peak
    im = plt.imshow( (H_traj+peak)/(2*peak), interpolation=interp, origin='lower', \
        extent=(x_tmp[0],x_tmp[-1],y_tmp[0],y_tmp[-1]) )
    im.set_cmap('seismic')
    
    plt.figure('occ')
    H_traj,y_tmp,x_tmp = np.histogram2d(y,x,bins=[y_edges,x_edges])
    H_traj = np.fliplr( H_traj.astype('d') )
    plt.imshow( H_traj,interpolation=interp,origin='lower' , \
        extent=(x_tmp[0],x_tmp[-1],y_tmp[0],y_tmp[-1]) )
    print '%d bin excluded by occupancy filter (%.2f s)' % \
        ( np.sum(np.logical_and(H_traj<OCC_THRD,H_traj>0)), OCC_THRD/fs )
    H_traj[ H_traj<OCC_THRD ] = 0.0

    plt.figure('heatmap_jet')
    H_spk,y_tmp,x_tmp = np.histogram2d(spk_y,spk_x,bins=[y_edges,x_edges])
    H_spk = np.fliplr( H_spk.astype('d') )
    H_rate = H_spk / H_traj * fs # Hz
    peak_rate = np.max( H_rate[np.isfinite(H_rate)] )
    plt.imshow( H_rate/peak_rate, interpolation=interp, origin='lower', \
        extent=(x_tmp[0],x_tmp[-1],y_tmp[0],y_tmp[-1]) )
    print 'Peak rate: %f' % peak_rate

    plt.figure('heatmap')
    H_spk,y_tmp,x_tmp = np.histogram2d(spk_y,spk_x,bins=[y_edges,x_edges])
    H_spk = np.fliplr( H_spk.astype('d') )
    H_rate = H_spk / (H_traj/fs) # Hz
    peak_rate = np.max( H_rate[np.isfinite(H_rate)] )
    H_rate[~np.isfinite(H_rate)] = -peak_rate 
    im = plt.imshow( (H_rate+peak_rate)/(2*peak_rate), \
        interpolation=interp,origin='lower', \
        extent=(x_tmp[0],x_tmp[-1],y_tmp[0],y_tmp[-1]) )
    im.set_cmap('seismic')
    #plot_edges( float(x_nbin)/WIDTH, float(y_nbin)/HEIGHT )
    plot_edges( 1, 1 )
    plt.axis([0,WIDTH,0,HEIGHT])
    
    #print x_tmp[-1],y_tmp[-1],x_nbin,y_nbin

    return H_traj, H_spk, H_rate
# end of FUNCTION plot_2db_data

